0Pricing
CUDA Academy · 강의

벡터 덧셈 커널

스레드 하나가 원소 한 쌍을 더합니다.

벡터 덧셈 커널은(는) CoddyKit의 무료 CUDA Academy 강의입니다. 이것은 4개 중 1번째 강의입니다. 아래에서 전체 강의를 무료로 읽을 수 있으며, 내장 코드 에디터와 24/7 AI 튜터와 함께 브라우저에서 직접 실습할 수 있습니다. 이 강의는 CUDA Academy 학습 경로의 일부이며, 진행 상황이 웹과 CoddyKit 앱에 동기화됩니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

이 강의의 일부는 아직 번역되지 않았으며 영어로 표시됩니다.

The Big Idea

Vector addition is the perfect first kernel: each output is just C[i] = A[i] + B[i]. Every element is independent, so they can all run at once. 🚀

One Thread, One Element

The whole trick is simple: you assign one thread to one element. Instead of looping over the array, thousands of threads each do a single add in parallel.

Marking It as a Kernel

A function that runs on the GPU is a kernel, marked with the __global__ qualifier. That word tells nvcc this code launches on the device.

__global__ void vecAdd(const float* A, const float* B, float* C, int n) {
    // body comes next
}

Kernels Return void

A kernel always has a void return type. There is no return value to hand back to the CPU, so results must be written into device memory instead.

Finding This Thread's Index

Each thread computes its own global index so it knows which element to handle. The classic formula combines the block and thread coordinates.

int i = blockIdx.x * blockDim.x + threadIdx.x;

The Single Line of Work

Once a thread knows its index i, the real work is one line. No loop, no branching, just one add per thread.

C[i] = A[i] + B[i];

Why a Bounds Check Matters

You usually launch more threads than elements, so add an if (i < n) guard. Without it, extra threads read past the array and crash. 🛡️

if (i < n) {
    C[i] = A[i] + B[i];
}

The Full Kernel

Put it together and the entire vecAdd kernel is just a few lines. Tiny code, but it runs across thousands of threads at once.

__global__ void vecAdd(const float* A, const float* B, float* C, int n) {
    int i = blockIdx.x * blockDim.x + threadIdx.x;
    if (i < n) C[i] = A[i] + B[i];
}

Pointers Live on the Device

The pointers A, B, and C must point to device memory. Hand a kernel a plain host pointer and it will read garbage or fault.

Mark Inputs as const

A and B are only read, so mark them const float*. This documents intent and lets the compiler optimize the read-only inputs more freely.

No Shared State Needed

Because every thread touches a different element, there are no races and no locks. This independence is exactly what makes the GPU shine here.

Quick Check

Why does the vector add kernel need an if (i < n) guard?

Recap

You wrote your first kernel: __global__ void vecAdd, one thread per element, a global index, and a bounds check. Simple code, massive parallelism. 🎉

자주 묻는 질문

“벡터 덧셈 커널” 강의는 무료인가요?

네 — “벡터 덧셈 커널” 전체 내용을 이 웹사이트에서 무료로 읽을 수 있습니다. 인터랙티브하게 실습하려면(내장 코드 에디터와 24/7 AI 튜터), CoddyKit PRO로 업그레이드하면 CUDA Academy 강의 전체를 잠금 해제할 수 있습니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

“벡터 덧셈 커널”에서 뭘 배우나요?

스레드 하나가 원소 한 쌍을 더합니다. 브라우저에서 직접 실행하는 실습 코드로 CUDA Academy을(를) 배우며, 24/7 AI 튜터가 강의를 진행하면서 질문에 답변해줍니다.

CUDA Academy을(를) 시작하는 데 경험이 필요한가요?

사전 경험은 필요하지 않습니다. CoddyKit의 CUDA Academy은(는) 초급자부터 고급 학습자까지를 위해 구성되어 있으므로, 여기서 시작하거나 처음부터 시작할 수 있으며 자신의 속도대로 진행할 수 있습니다. 이것은 4개 중 1번째 강의입니다.

“벡터 덧셈 커널” 강의는 얼마나 걸리나요?

대부분의 CoddyKit 강의는 약 5~10분이 소요됩니다. 각 강의는 간결하고 인터랙티브하여 꾸준한 진행이 가능하며, 웹과 앱에서 중단한 부분부터 바로 시작할 수 있습니다.

이 CUDA Academy 강의에서 코드를 작성하고 실행할 수 있나요?

네. 모든 CUDA Academy 강의에는 내장 코드 에디터가 포함되어 있으므로, 브라우저에서 바로 실제 코드를 작성하고 실행한 후 즉시 AI 피드백을 받을 수 있습니다 — 로컬 설정이 필요 없습니다.

이 강의의 모든 강의

  1. 벡터 덧셈 커널
  2. 호스트 측 연결하기
  3. CPU에서 결과 검증하기
  4. 첫 성능 향상 시간 측정하기
← CUDA Academy(으)로 돌아가기